@@ -20,10 +20,10 @@ from __future__ import division
 from __future__ import absolute_import
 import base64
 import json
-import urllib
 import warnings
 
 import six
+from six.moves import urllib
 
 import gitlab
 from gitlab.base import *  # noqa
@@ -799,9 +799,7 @@ class ProjectCommit(GitlabObject):
         """
         url = '/projects/%s/repository/commits/%s/builds' % (self.project_id,
                                                              self.id)
-        return self.gitlab._raw_list(url, ProjectBuild,
-                                     {'project_id': self.project_id},
-                                     **kwargs)
+        return self.gitlab._raw_list(url, ProjectBuild, **kwargs)
 
     def cherry_pick(self, branch, **kwargs):
         """Cherry-pick a commit into a branch.
@@ -1254,9 +1252,7 @@ class ProjectMergeRequest(GitlabObject):
         """
         url = ('/projects/%s/merge_requests/%s/closes_issues' %
                (self.project_id, self.id))
-        return self.gitlab._raw_list(url, ProjectIssue,
-                                     {'project_id': self.project_id},
-                                     **kwargs)
+        return self.gitlab._raw_list(url, ProjectIssue, **kwargs)
 
     def commits(self, **kwargs):
         """List the merge request commits.
@@ -1270,9 +1266,7 @@ class ProjectMergeRequest(GitlabObject):
         """
         url = ('/projects/%s/merge_requests/%s/commits' %
                (self.project_id, self.id))
-        return self.gitlab._raw_list(url, ProjectCommit,
-                                     {'project_id': self.project_id},
-                                     **kwargs)
+        return self.gitlab._raw_list(url, ProjectCommit, **kwargs)
 
     def changes(self, **kwargs):
         """List the merge request changes.
@@ -1420,9 +1414,7 @@ class ProjectMilestone(GitlabObject):
 
     def issues(self, **kwargs):
         url = "/projects/%s/milestones/%s/issues" % (self.project_id, self.id)
-        return self.gitlab._raw_list(url, ProjectIssue,
-                                     {'project_id': self.project_id},
-                                     **kwargs)
+        return self.gitlab._raw_list(url, ProjectIssue, **kwargs)
 
     def merge_requests(self, **kwargs):
         """List the merge requests related to this milestone
@@ -1436,9 +1428,7 @@ class ProjectMilestone(GitlabObject):
         """
         url = ('/projects/%s/milestones/%s/merge_requests' %
                (self.project_id, self.id))
-        return self.gitlab._raw_list(url, ProjectMergeRequest,
-                                     {'project_id': self.project_id},
-                                     **kwargs)
+        return self.gitlab._raw_list(url, ProjectMergeRequest, **kwargs)
 
 
 class ProjectMilestoneManager(BaseManager):
@@ -1851,7 +1841,7 @@ class Project(GitlabObject):
         url = "/projects/%s/repository/tree" % (self.id)
         params = []
         if path:
-            params.append(urllib.urlencode({'path': path}))
+            params.append(urllib.parse.urlencode({'path': path}))
         if ref_name:
             params.append("ref_name=%s" % ref_name)
         if params:
@@ -1882,7 +1872,7 @@ class Project(GitlabObject):
             GitlabGetError: If the server fails to perform the request.
         """
         url = "/projects/%s/repository/blobs/%s" % (self.id, sha)
-        url += '?%s' % (urllib.urlencode({'filepath': filepath}))
+        url += '?%s' % (urllib.parse.urlencode({'filepath': filepath}))
         r = self.gitlab._raw_get(url, streamed=streamed, **kwargs)
         raise_error_from_response(r, GitlabGetError)
         return utils.response_content(r, streamed, action, chunk_size)
